@@ -2,9 +2,8 @@
 # Copyright 2019 TD Ameritrade. Released under the terms of the 3-Clause BSD license.
 # STUMPY is a trademark of TD Ameritrade IP Company, Inc. All rights reserved.
 
-from . import aamp, aamped
+from . import aamp, aamped, mpdist
 from .core import _mass_absolute_distance_matrix
-from .mpdist import _mpdist, _mpdist_vect
 
 
 def _aampdist_vect(
@@ -38,23 +37,23 @@ def _aampdist_vect(
     k : int, default None
         Specify the `k`th value in the concatenated matrix profiles to return. When `k`
         is not `None`, then the `percentage` parameter is ignored. This parameter is
-        ignored when `k_func` is not None.
+        ignored when `custom_func` is not None.
 
     custom_func : object, default None
         A custom user defined function for selecting the desired value from the
-        sorted `P_ABBA` array. This function may need to leverage `functools.partial`
+        unsorted `P_ABBA` array. This function may need to leverage `functools.partial`
         and should take `P_ABBA` as its only input parameter and return a single
         `MPdist` value. The `percentage` and `k` parameters are ignored when
         `custom_func` is not None.
     """
-    return _mpdist_vect(
+    return mpdist._mpdist_vect(
         Q,
         T,
         m,
-        distance_matrix_func=_mass_absolute_distance_matrix,
         percentage=percentage,
         k=k,
         custom_func=custom_func,
+        distance_matrix_func=_mass_absolute_distance_matrix,
     )
 
 
@@ -65,10 +64,10 @@ def aampdist(T_A, T_B, m, percentage=0.05, k=None):
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -85,6 +84,10 @@ def aampdist(T_A, T_B, m, percentage=0.05, k=None):
         The percentage of distances that will be used to report `mpdist`. The value
         is between 0.0 and 1.0.
 
+    k : int
+        Specify the `k`th value in the concatenated matrix profiles to return. When `k`
+        is not `None`, then the `percentage` parameter is ignored.
+
     Returns
     -------
     MPdist : float
@@ -97,7 +100,7 @@ def aampdist(T_A, T_B, m, percentage=0.05, k=None):
 
     See Section III
     """
-    return _mpdist(T_A, T_B, m, percentage, k, mp_func=aamp)
+    return mpdist._mpdist(T_A, T_B, m, percentage, k, mp_func=aamp)
 
 
 def aampdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
@@ -108,10 +111,10 @@ def aampdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -150,4 +153,6 @@ def aampdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
 
     See Section III
     """
-    return _mpdist(T_A, T_B, m, percentage, k, dask_client=dask_client, mp_func=aamped)
+    return mpdist._mpdist(
+        T_A, T_B, m, percentage, k, dask_client=dask_client, mp_func=aamped
+    )
