@@ -7,7 +7,7 @@ import copy
 import numpy as np
 import scipy.stats
 
-from . import core
+from . import core, config
 
 
 def _nnmark(I):
@@ -32,7 +32,7 @@ def _nnmark(I):
 
     This is a fast and vectorized implementation of the nnmark algorithm.
     """
-    I = I.astype(int)
+    I = I.astype(np.int64)
 
     # Replace index values that are less than zero with its own positional index
     idx = np.argwhere(I < 0).flatten()
@@ -235,7 +235,8 @@ def fluss(I, L, n_regimes, excl_factor=5, custom_iac=None):
     for static data (i.e., batch processing)
 
     Essentially, this is a wrapper to compute the corrected arc curve and
-    regime locations.
+    regime locations. Note that since the matrix profile indices, `I`, are pre-computed,
+    this function is agnostic to subsequence normalization.
 
     Parameters
     ----------
@@ -288,7 +289,7 @@ def fluss(I, L, n_regimes, excl_factor=5, custom_iac=None):
     return cac, regime_locs
 
 
-class floss(object):
+class floss:
     """
     Compute the Fast Low-cost Online Semantic Segmentation (FLOSS) for
     streaming data
@@ -335,6 +336,9 @@ class floss(object):
         A custom idealized arc curve (IAC) that will used for correcting the
         arc curve
 
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances
+
     Attributes
     ----------
     cac_1d_ : ndarray
@@ -370,7 +374,16 @@ class floss(object):
     """
 
     def __init__(
-        self, mp, T, m, L, excl_factor=5, n_iter=1000, n_samples=1000, custom_iac=None
+        self,
+        mp,
+        T,
+        m,
+        L,
+        excl_factor=5,
+        n_iter=1000,
+        n_samples=1000,
+        custom_iac=None,
+        normalize=True,
     ):
         """
         Initialize the FLOSS object
@@ -416,6 +429,10 @@ class floss(object):
         custom_iac : ndarray, default None
             A custom idealized arc curve (IAC) that will used for correcting the
             arc curve
+
+        normalize : bool, default True
+            When set to `True`, this z-normalizes subsequences prior to computing
+            distances
         """
         self._mp = copy.deepcopy(np.asarray(mp))
         self._T = copy.deepcopy(np.asarray(T))
@@ -425,6 +442,7 @@ class floss(object):
         self._n_iter = n_iter
         self._n_samples = n_samples
         self._custom_iac = custom_iac
+        self._normalize = normalize
         self._k = self._mp.shape[0]
         self._n = self._T.shape[0]
         self._last_idx = self._n - self._m + 1  # Depends on the changing length of `T`
@@ -453,11 +471,17 @@ class floss(object):
         # Note that any -1 indices must have a np.inf matrix profile value
         right_indices = [np.arange(IR, IR + self._m) for IR in self._mp[:, 3].tolist()]
         right_nn[:] = self._T[np.array(right_indices)]
-        self._mp[:, 0] = np.linalg.norm(
-            core.z_norm(core.rolling_window(self._T, self._m), 1)
-            - core.z_norm(right_nn, 1),
-            axis=1,
-        )
+        if self._normalize:
+            self._mp[:, 0] = np.linalg.norm(
+                core.z_norm(core.rolling_window(self._T, self._m), 1)
+                - core.z_norm(right_nn, 1),
+                axis=1,
+            )
+        else:
+            self._mp[:, 0] = np.linalg.norm(
+                core.rolling_window(self._T, self._m) - right_nn,
+                axis=1,
+            )
         inf_indices = np.argwhere(self._mp[:, 3] < 0).flatten()
         self._mp[inf_indices, 0] = np.inf
         self._mp[inf_indices, 3] = inf_indices
@@ -495,7 +519,7 @@ class floss(object):
         if not np.isfinite(t):
             self._finite_T[-1] = 0.0
         self._finite_Q[-1] = self._finite_T[-1]
-        excl_zone = int(np.ceil(self._m / 4))
+        excl_zone = int(np.ceil(self._m / config.STUMPY_EXCL_ZONE_DENOM))
         # Note that the start of the exclusion zone is relative to
         # the unchanging length of the matrix profile index
         zone_start = max(0, self._k - excl_zone)
@@ -508,9 +532,12 @@ class floss(object):
         self._mp[-1, 3] = self._last_idx
 
         # Ingress
-        M_T, Σ_T = core.compute_mean_std(self._T, self._m)
+        if self._normalize:
+            M_T, Σ_T = core.compute_mean_std(self._T, self._m)
+            D = core.mass(self._finite_Q, self._finite_T, M_T, Σ_T)
+        else:
+            D = core.mass_absolute(self._T[-self._m :], self._T)
 
-        D = core.mass(self._finite_Q, self._finite_T, M_T, Σ_T)
         D[zone_start:] = np.inf
 
         T_subseq_isfinite = core.rolling_isfinite(self._T_isfinite, self._m)
@@ -541,25 +568,25 @@ class floss(object):
         """
         Get the updated 1-dimensional corrected arc curve (CAC_1D)
         """
-        return self._cac.astype(np.float)
+        return self._cac.astype(np.float64)
 
     @property
     def P_(self):
         """
         Get the updated matrix profile
         """
-        return self._mp[:, 0].astype(np.float)
+        return self._mp[:, 0].astype(np.float64)
 
     @property
     def I_(self):
         """
         Get the updated (right) matrix profile indices
         """
-        return self._mp[:, 3].astype(np.int)
+        return self._mp[:, 3].astype(np.int64)
 
     @property
     def T_(self):
         """
         Get the updated time series, `T`
         """
-        return self._T.astype(np.float)
+        return self._T.astype(np.float64)
