@@ -10,6 +10,7 @@ import numpy as np
 from numba import cuda
 
 from . import core, config
+from .gpu_aamp import gpu_aamp
 
 logger = logging.getLogger(__name__)
 
@@ -371,7 +372,8 @@ def _gpu_stump(
     return profile_fname, indices_fname
 
 
-def gpu_stump(T_A, m, T_B=None, ignore_trivial=True, device_id=0):
+@core.non_normalized(gpu_aamp)
+def gpu_stump(T_A, m, T_B=None, ignore_trivial=True, device_id=0, normalize=True):
     """
     Compute the z-normalized matrix profile with one or more GPU devices
 
@@ -401,6 +403,11 @@ def gpu_stump(T_A, m, T_B=None, ignore_trivial=True, device_id=0):
         computation. A list of all valid device ids can be obtained by
         executing `[device.id for device in numba.cuda.list_devices()]`.
 
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this function gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` function decorator.
+
     Returns
     -------
     out : ndarray
@@ -469,7 +476,9 @@ def gpu_stump(T_A, m, T_B=None, ignore_trivial=True, device_id=0):
     n = T_B.shape[0]
     k = T_A.shape[0] - m + 1
     l = n - m + 1
-    excl_zone = int(np.ceil(m / 4))  # See Definition 3 and Figure 3
+    excl_zone = int(
+        np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
+    )  # See Definition 3 and Figure 3
 
     T_A_fname = core.array_to_temp_file(T_A)
     T_B_fname = core.array_to_temp_file(T_B)
