@@ -7,6 +7,7 @@ import math
 
 from . import stump, stumped, core
 from .core import _mass_distance_matrix
+from .aampdist import aampdist, aampdisted
 
 
 def _compute_P_ABBA(
@@ -19,10 +20,10 @@ def _compute_P_ABBA(
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -80,15 +81,15 @@ def _select_P_ABBA_value(P_ABBA, k, custom_func=None):
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
     P_ABBA : ndarray
-        A pre-sorted array resulting from the concatenation of the outputs from an
+        An unsorted array resulting from the concatenation of the outputs from an
         AB-joinand BA-join for two time series, `T_A` and `T_B`
 
     k : int
@@ -97,7 +98,7 @@ def _select_P_ABBA_value(P_ABBA, k, custom_func=None):
 
     custom_func : object, default None
         A custom user defined function for selecting the desired value from the
-        sorted `P_ABBA` array. This function may need to leverage `functools.partial`
+        unsorted `P_ABBA` array. This function may need to leverage `functools.partial`
         and should take `P_ABBA` as its only input parameter and return a single
         `MPdist` value. The `percentage` and `k` parameters are ignored when
         `custom_func` is not None.
@@ -111,10 +112,12 @@ def _select_P_ABBA_value(P_ABBA, k, custom_func=None):
     if custom_func is not None:
         MPdist = custom_func(P_ABBA)
     else:
-        MPdist = P_ABBA[k]
+        partition = np.partition(P_ABBA, k)
+        MPdist = partition[k]
         if ~np.isfinite(MPdist):
-            k = max(0, np.count_nonzero(np.isfinite(P_ABBA[:k])) - 1)
-            MPdist = P_ABBA[k]
+            partition[:k].sort()
+            k = max(0, np.count_nonzero(np.isfinite(partition[:k])) - 1)
+            MPdist = partition[k]
 
     return MPdist
 
@@ -136,10 +139,10 @@ def _mpdist(
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -179,7 +182,7 @@ def _mpdist(
 
     custom_func : object, default None
         A custom user defined function for selecting the desired value from the
-        sorted `P_ABBA` array. This function may need to leverage `functools.partial`
+        unsorted `P_ABBA` array. This function may need to leverage `functools.partial`
         and should take `P_ABBA` as its only input parameter and return a single
         `MPdist` value. The `percentage` and `k` parameters are ignored when
         `custom_func` is not None.
@@ -201,13 +204,11 @@ def _mpdist(
     P_ABBA = np.empty(n_A - m + 1 + n_B - m + 1, dtype=np.float64)
 
     _compute_P_ABBA(T_A, T_B, m, P_ABBA, dask_client, device_id, mp_func)
-    P_ABBA.sort()
 
     if k is not None:
         k = min(int(k), P_ABBA.shape[0] - 1)
     else:
-        percentage = min(percentage, 1.0)
-        percentage = max(percentage, 0.0)
+        percentage = np.clip(percentage, 0.0, 1.0)
         k = min(math.ceil(percentage * (n_A + n_B)), n_A - m + 1 + n_B - m + 1 - 1)
 
     MPdist = _select_P_ABBA_value(P_ABBA, k, custom_func)
@@ -219,10 +220,10 @@ def _mpdist_vect(
     Q,
     T,
     m,
-    distance_matrix_func=_mass_distance_matrix,
     percentage=0.05,
     k=None,
     custom_func=None,
+    distance_matrix_func=_mass_distance_matrix,
 ):
     """
     Compute the matrix profile distance measure vector between `Q` and each subsequence,
@@ -239,9 +240,6 @@ def _mpdist_vect(
     m : int
         Window size
 
-    distance_matrix_func : object, default _mass_distance_matrix
-        The function to use to compute the distance matrix between `Q` and `T`
-
     percentage : float, 0.05
         The percentage of distances that will be used to report `mpdist`. The value
         is between 0.0 and 1.0. This parameter is ignored when `k` is not `None` or when
@@ -250,14 +248,17 @@ def _mpdist_vect(
     k : int, default None
         Specify the `k`th value in the concatenated matrix profiles to return. When `k`
         is not `None`, then the `percentage` parameter is ignored. This parameter is
-        ignored when `k_func` is not None.
+        ignored when `custom_func` is not None.
 
     custom_func : object, default None
         A custom user defined function for selecting the desired value from the
-        sorted `P_ABBA` array. This function may need to leverage `functools.partial`
+        unsorted `P_ABBA` array. This function may need to leverage `functools.partial`
         and should take `P_ABBA` as its only input parameter and return a single
         `MPdist` value. The `percentage` and `k` parameters are ignored when
         `custom_func` is not None.
+
+    distance_matrix_func : object, default _mass_distance_matrix
+        The function to use to compute the distance matrix between `Q` and `T`
     """
     j = Q.shape[0] - m + 1  # `k` is reserved for `P_ABBA` selection
     l = T.shape[0] - m + 1
@@ -266,8 +267,7 @@ def _mpdist_vect(
     P_ABBA = np.empty(2 * j)
 
     if k is None:
-        percentage = min(percentage, 1.0)
-        percentage = max(percentage, 0.0)
+        percentage = np.clip(percentage, 0.0, 1.0)
         k = min(math.ceil(percentage * (2 * Q.shape[0])), 2 * j - 1)
 
     k = min(int(k), P_ABBA.shape[0] - 1)
@@ -280,23 +280,23 @@ def _mpdist_vect(
     for i in range(MPdist_vect.shape[0]):
         P_ABBA[:j] = rolling_row_min[:, i]
         P_ABBA[j:] = col_min[i : i + j]
-        P_ABBA.sort()
         MPdist_vect[i] = _select_P_ABBA_value(P_ABBA, k, custom_func)
 
     return MPdist_vect
 
 
-def mpdist(T_A, T_B, m, percentage=0.05, k=None):
+@core.non_normalized(aampdist)
+def mpdist(T_A, T_B, m, percentage=0.05, k=None, normalize=True):
     """
-    Compute the  z-normalized matrix profile distance (MPdist) measure between any two
+    Compute the z-normalized matrix profile distance (MPdist) measure between any two
     time series
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -313,6 +313,15 @@ def mpdist(T_A, T_B, m, percentage=0.05, k=None):
         The percentage of distances that will be used to report `mpdist`. The value
         is between 0.0 and 1.0.
 
+    k : int
+        Specify the `k`th value in the concatenated matrix profiles to return. When `k`
+        is not `None`, then the `percentage` parameter is ignored.
+
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this function gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` function decorator.
+
     Returns
     -------
     MPdist : float
@@ -325,20 +334,23 @@ def mpdist(T_A, T_B, m, percentage=0.05, k=None):
 
     See Section III
     """
-    return _mpdist(T_A, T_B, m, percentage, k, mp_func=stump)
+    MPdist = _mpdist(T_A, T_B, m, percentage, k, mp_func=stump)
+
+    return MPdist
 
 
-def mpdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
+@core.non_normalized(aampdisted)
+def mpdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None, normalize=True):
     """
     Compute the z-normalized matrix profile distance (MPdist) measure between any two
     time series with a distributed dask cluster
 
     The MPdist distance measure considers two time series to be similar if they share
     many subsequences, regardless of the order of matching subsequences. MPdist
-    concatenates and sorts the output of an AB-join and a BA-join and returns the value
-    of the `k`th smallest number as the reported distance. Note that MPdist is a
-    measure and not a metric. Therefore, it does not obey the triangular inequality but
-    the method is highly scalable.
+    concatenates the output of an AB-join and a BA-join and returns the `k`th smallest
+    value as the reported distance. Note that MPdist is a measure and not a metric.
+    Therefore, it does not obey the triangular inequality but the method is highly
+    scalable.
 
     Parameters
     ----------
@@ -365,6 +377,11 @@ def mpdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
         Specify the `k`th value in the concatenated matrix profiles to return. When `k`
         is not `None`, then the `percentage` parameter is ignored.
 
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this function gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` function decorator.
+
     Returns
     -------
     MPdist : float
@@ -377,4 +394,8 @@ def mpdisted(dask_client, T_A, T_B, m, percentage=0.05, k=None):
 
     See Section III
     """
-    return _mpdist(T_A, T_B, m, percentage, k, dask_client=dask_client, mp_func=stumped)
+    MPdist = _mpdist(
+        T_A, T_B, m, percentage, k, dask_client=dask_client, mp_func=stumped
+    )
+
+    return MPdist
