@@ -5,9 +5,10 @@
 import logging
 
 import numpy as np
-from numba import njit, config
+from numba import njit
+import numba
 
-from . import core
+from . import core, scraamp, config
 from .stump import _stump
 
 logger = logging.getLogger(__name__)
@@ -65,7 +66,8 @@ def _prescrump(
         The subsequence index in `T_B` that corresponds to `Q`
 
     s : int
-        The sampling interval that defaults to `int(np.ceil(m / 4))`
+        The sampling interval that defaults to
+        `int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))`
 
     squared_distance_profile : ndarray
         A reusable array to store the computed squared distance profile
@@ -99,53 +101,54 @@ def _prescrump(
     P_squared[i] = squared_distance_profile[I[i]]
     if P_squared[i] == np.inf:  # pragma: no cover
         I[i] = -1
-
-    j = I[i]
-    # Given the squared distance, work backwards and compute QT
-    QT_j = (m - P_squared[i] / 2.0) * (Σ_T[j] * σ_Q[i]) + (m * M_T[j] * μ_Q[i])
-    QT_j_prime = QT_j
-    for k in range(1, min(s, l - max(i, j))):
-        QT_j = (
-            QT_j
-            - T_B[i + k - 1] * T_A[j + k - 1]
-            + T_B[i + k + m - 1] * T_A[j + k + m - 1]
-        )
-        D_squared = core._calculate_squared_distance(
-            m,
-            QT_j,
-            M_T[i + k],
-            Σ_T[i + k],
-            μ_Q[j + k],
-            σ_Q[j + k],
-        )
-        if D_squared < P_squared[i + k]:
-            P_squared[i + k] = D_squared
-            I[i + k] = j + k
-        if D_squared < P_squared[j + k]:
-            P_squared[j + k] = D_squared
-            I[j + k] = i + k
-    QT_j = QT_j_prime
-    for k in range(1, min(s, i + 1, j + 1)):
-        QT_j = QT_j - T_B[i - k + m] * T_A[j - k + m] + T_B[i - k] * T_A[j - k]
-        D_squared = core._calculate_squared_distance(
-            m,
-            QT_j,
-            M_T[i - k],
-            Σ_T[i - k],
-            μ_Q[j - k],
-            σ_Q[j - k],
-        )
-        if D_squared < P_squared[i - k]:
-            P_squared[i - k] = D_squared
-            I[i - k] = j - k
-        if D_squared < P_squared[j - k]:
-            P_squared[j - k] = D_squared
-            I[j - k] = i - k
+    else:
+        j = I[i]
+        # Given the squared distance, work backwards and compute QT
+        QT_j = (m - P_squared[i] / 2.0) * (Σ_T[j] * σ_Q[i]) + (m * M_T[j] * μ_Q[i])
+        QT_j_prime = QT_j
+        for k in range(1, min(s, l - max(i, j))):
+            QT_j = (
+                QT_j
+                - T_B[i + k - 1] * T_A[j + k - 1]
+                + T_B[i + k + m - 1] * T_A[j + k + m - 1]
+            )
+            D_squared = core._calculate_squared_distance(
+                m,
+                QT_j,
+                M_T[i + k],
+                Σ_T[i + k],
+                μ_Q[j + k],
+                σ_Q[j + k],
+            )
+            if D_squared < P_squared[i + k]:
+                P_squared[i + k] = D_squared
+                I[i + k] = j + k
+            if D_squared < P_squared[j + k]:
+                P_squared[j + k] = D_squared
+                I[j + k] = i + k
+        QT_j = QT_j_prime
+        for k in range(1, min(s, i + 1, j + 1)):
+            QT_j = QT_j - T_B[i - k + m] * T_A[j - k + m] + T_B[i - k] * T_A[j - k]
+            D_squared = core._calculate_squared_distance(
+                m,
+                QT_j,
+                M_T[i - k],
+                Σ_T[i - k],
+                μ_Q[j - k],
+                σ_Q[j - k],
+            )
+            if D_squared < P_squared[i - k]:
+                P_squared[i - k] = D_squared
+                I[i - k] = j - k
+            if D_squared < P_squared[j - k]:
+                P_squared[j - k] = D_squared
+                I[j - k] = i - k
 
     return
 
 
-def prescrump(T_A, m, T_B=None, s=None):
+@core.non_normalized(scraamp.prescraamp)
+def prescrump(T_A, m, T_B=None, s=None, normalize=True):
     """
     A convenience wrapper around the Numba JIT-compiled parallelized `_prescrump`
     function which computes the approximate matrix profile according to the preSCRIMP
@@ -164,7 +167,13 @@ def prescrump(T_A, m, T_B=None, s=None):
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
     s : int, default None
-        The sampling interval that defaults to `int(np.ceil(m / 4))`
+        The sampling interval that defaults to
+        `int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))`
+
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this function gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` function decorator.
 
     Returns
     -------
@@ -188,7 +197,7 @@ def prescrump(T_A, m, T_B=None, s=None):
 
     if T_B is None:
         T_B = T_A
-        excl_zone = int(np.ceil(m / 4))
+        excl_zone = int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))
     else:
         excl_zone = None
 
@@ -239,7 +248,12 @@ def prescrump(T_A, m, T_B=None, s=None):
     return P, I
 
 
-class scrump(object):
+@core.non_normalized(
+    scraamp.scraamp,
+    exclude=["normalize", "pre_scrump", "pre_scraamp"],
+    replace={"pre_scrump": "pre_scraamp"},
+)
+class scrump:
     """
     Compute an approximate z-normalized matrix profile
 
@@ -271,9 +285,15 @@ class scrump(object):
         SCRIMP++ and may lead to faster convergence
 
     s : int
-        The size of the PreSCRIMP fixed interval. If `pre-scrump=True` and `s=None`,
-        then `s` will automatically be set to `s=int(np.ceil(m/4))`, the size of
-        the exclusion zone.
+        The size of the PreSCRIMP fixed interval. If `pre_scrump=True` and `s=None`,
+        then `s` will automatically be set to
+        `s=int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))`, the size of the exclusion
+        zone.
+
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this class gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` class decorator.
 
     Attributes
     ----------
@@ -307,6 +327,7 @@ class scrump(object):
         percentage=0.01,
         pre_scrump=False,
         s=None,
+        normalize=True,
     ):
         """
         Initialize the `scrump` object
@@ -336,9 +357,15 @@ class scrump(object):
             SCRIMP++
 
         s : int, default None
-            The size of the PreSCRIMP fixed interval. If `pre-scrump=True` and `s=None`,
-            then `s` will automatically be set to `s=int(np.ceil(m/4))`, the size of
-            the exclusion zone.
+            The size of the PreSCRIMP fixed interval. If `pre_scrump=True` and `s=None`,
+            then `s` will automatically be set to
+            `s=int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))`, the size of the
+            exclusion zone.
+
+        normalize : bool, default True
+            When set to `True`, this z-normalizes subsequences prior to computing
+            distances. Otherwise, this class gets re-routed to its complementary
+            non-normalized equivalent set in the `@core.non_normalized` class decorator.
         """
         self._ignore_trivial = ignore_trivial
 
@@ -401,14 +428,14 @@ class scrump(object):
         self._P[:, :] = np.inf
         self._I[:, :] = -1
 
-        self._excl_zone = int(np.ceil(self._m / 4))
+        self._excl_zone = int(np.ceil(self._m / config.STUMPY_EXCL_ZONE_DENOM))
 
         if s is None:
             s = self._excl_zone
 
         if pre_scrump:
             if self._ignore_trivial:
-                P, I = prescrump(self._T_A, self._m, s=s)
+                P, I = prescrump(T_A, m, s=s)
             else:
                 P, I = prescrump(T_A, m, T_B=T_B, s=s)
             for i in range(P.shape[0]):
@@ -420,21 +447,27 @@ class scrump(object):
             self._diags = np.random.permutation(
                 range(self._excl_zone + 1, self._n_A - self._m + 1)
             )
+            if self._diags.shape[0] == 0:  # pragma: no cover
+                max_m = core.get_max_window_size(self._T_A.shape[0])
+                raise ValueError(
+                    f"The window size, `m = {self._m}`, is too long for a self join. "
+                    f"Please try a value of `m <= {max_m}`"
+                )
         else:
             self._diags = np.random.permutation(
                 range(-(self._n_A - self._m + 1) + 1, self._n_B - self._m + 1)
             )
 
-        self._n_threads = config.NUMBA_NUM_THREADS
-        self._percentage = min(percentage, 1.0)
-        self._percentage = max(percentage, 0.0)
+        self._n_threads = numba.config.NUMBA_NUM_THREADS
+        self._percentage = np.clip(percentage, 0.0, 1.0)
         self._n_chunks = int(np.ceil(1.0 / percentage))
         self._ndist_counts = core._count_diagonal_ndist(
             self._diags, self._m, self._n_A, self._n_B
         )
         self._chunk_diags_ranges = core._get_array_ranges(
-            self._ndist_counts, self._n_chunks
+            self._ndist_counts, self._n_chunks, truncate=True
         )
+        self._n_chunks = self._chunk_diags_ranges.shape[0]
         self._chunk_idx = 0
 
     def update(self):
@@ -485,25 +518,25 @@ class scrump(object):
         """
         Get the updated matrix profile
         """
-        return self._P[:, 0].astype(np.float)
+        return self._P[:, 0].astype(np.float64)
 
     @property
     def I_(self):
         """
         Get the updated matrix profile indices
         """
-        return self._I[:, 0].astype(np.int)
+        return self._I[:, 0].astype(np.int64)
 
     @property
     def left_I_(self):
         """
         Get the updated left matrix profile indices
         """
-        return self._I[:, 1].astype(np.int)
+        return self._I[:, 1].astype(np.int64)
 
     @property
     def right_I_(self):
         """
         Get the updated right matrix profile indices
         """
-        return self._I[:, 2].astype(np.int)
+        return self._I[:, 2].astype(np.int64)
