@@ -6,7 +6,7 @@ import logging
 
 import numpy as np
 
-from . import core, stamp
+from . import core, stamp, config
 
 logger = logging.getLogger(__name__)
 
@@ -98,7 +98,9 @@ def _stomp(T_A, m, T_B=None, ignore_trivial=True):
 
     n = T_A.shape[0]
     l = n - m + 1
-    excl_zone = int(np.ceil(m / 4))  # See Definition 3 and Figure 3
+    excl_zone = int(
+        np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
+    )  # See Definition 3 and Figure 3
 
     out = np.empty((l, 4), dtype=object)
 
