@@ -3,13 +3,16 @@
 # STUMPY is a trademark of TD Ameritrade IP Company, Inc. All rights reserved.
 
 import numpy as np
-from . import core, stump
+from . import core, stump, config
+from .aampi import aampi
 
 
-class stumpi(object):
+@core.non_normalized(aampi)
+class stumpi:
     """
-    Compute an incremental z-normalized matrix profile for streaming data. This
-    is based on the on-line STOMPI and STAMPI algorithms.
+    Compute an incremental z-normalized matrix profile for streaming data
+
+    This is based on the on-line STOMPI and STAMPI algorithms.
 
     Parameters
     ----------
@@ -20,14 +23,15 @@ class stumpi(object):
     m : int
         Window size
 
-    excl_zone : int, default None
-        The half width for the exclusion zone relative to the current
-        sliding window
-
     egress : bool, default True
         If set to `True`, the oldest data point in the time series is removed and
         the time series length remains constant rather than forever increasing
 
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this class gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` class decorator.
+
     Attributes
     ----------
     P_ : ndarray
@@ -62,7 +66,7 @@ class stumpi(object):
     Note that line 11 is missing an important `sqrt` operation!
     """
 
-    def __init__(self, T, m, excl_zone=None, egress=True):
+    def __init__(self, T, m, egress=True, normalize=True):
         """
         Initialize the `stumpi` object
 
@@ -75,30 +79,28 @@ class stumpi(object):
         m : int
             Window size
 
-        excl_zone : int, default None
-            The half width for the exclusion zone relative to the current
-            sliding window
-
         egress : bool, default True
             If set to `True`, the oldest data point in the time series is removed and
             the time series length remains constant rather than forever increasing
+
+        normalize : bool, default True
+            When set to `True`, this z-normalizes subsequences prior to computing
+            distances. Otherwise, this class gets re-routed to its complementary
+            non-normalized equivalent set in the `@core.non_normalized` class decorator.
         """
         self._T = T.copy()
         self._T = np.asarray(self._T)
         core.check_dtype(self._T)
         self._m = m
         self._n = self._T.shape[0]
-        if excl_zone is not None:  # pragma: no cover
-            self._excl_zone = excl_zone
-        else:
-            self._excl_zone = int(np.ceil(self._m / 4))
+        self._excl_zone = int(np.ceil(self._m / config.STUMPY_EXCL_ZONE_DENOM))
         self._T_isfinite = np.isfinite(self._T)
         self._egress = egress
 
         mp = stump(self._T, self._m)
-        self._P = mp[:, 0]
-        self._I = mp[:, 1]
-        self._left_I = mp[:, 2]
+        self._P = mp[:, 0].astype(np.float64)
+        self._I = mp[:, 1].astype(np.int64)
+        self._left_I = mp[:, 2].astype(np.int64)
         self._left_P = np.empty(self._P.shape)
         self._left_P[:] = np.inf
 
